@@ -19,10 +19,6 @@ try:
     from win32com import *
 except ImportError:
     pass
-try:
-    import win32mica as mc
-except ImportError:
-    pass
 try:
     import darkdetect
 except ImportError:
@@ -100,9 +96,12 @@ def window_light(window: tk.Tk):
     dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), DWMWA_USE_IMMERSIVE_DARK_MODE, False)
 
 
-def window_acrylic(window: tk.Tk, Dark=False):
+def window_acrylic(window: tk.Tk, Dark=False, Low: bool = False):
     from BlurWindow.blurWindow import GlobalBlur
-    GlobalBlur(GetParent(window.winfo_id()), Acrylic=True, Dark=True, QWidget=window.winfo_id)
+    if Low:
+        GlobalBlur(GetParent(window.winfo_id()), hexColor=True, Dark=Dark, QWidget=window)
+    else:
+        GlobalBlur(GetParent(window.winfo_id()), Dark=Dark, QWidget=window)
 
 
 def window_long(window: tk.Tk, long):
@@ -135,10 +134,20 @@ def window_alpha(window: tk.Tk, alpha: int):
 
 
 def window_mica_light(window: tk.Tk):
+    try:
+        import win32mica as mc
+        mc.debugging = False
+    except ImportError:
+        pass
     mc.ApplyMica(GetParent(window.winfo_id()), mc.MICAMODE.LIGHT)
 
 
 def window_mica_dark(window: tk.Tk):
+    try:
+        import win32mica as mc
+        mc.debugging = False
+    except ImportError:
+        pass
     mc.ApplyMica(GetParent(window.winfo_id()), mc.MICAMODE.DARK)
 
 
@@ -824,18 +833,23 @@ class DevWindow(tk.Tk):
         self.geometry("630x300")
         self.iconbitmap(Icon_Empty)
 
-    def wm_acrylic(self, mode: Literal["auto", "light", "dark"] = Auto, mica: bool = True):
+    def wm_acrylic(self, mode: Literal["auto", "light", "dark"] = Auto, mica: bool = True, low: bool = False):
         if mica:
             self.mica(mode)
+
         if mode == "auto":
             if darkdetect.isLight():
-                window_acrylic(self, Dark=False)
+                window_acrylic(self, Dark=False, Low=low)
+                self.configure(background="#d3d3d3")
             if darkdetect.isDark():
-                window_acrylic(self, Dark=True)
+                window_acrylic(self, Dark=True, Low=low)
+                self.configure(background="#000000")
         elif mode == "light":
-            window_acrylic(self, Dark=False)
+            window_acrylic(self, Dark=False, Low=low)
+            self.configure(background="#d3d3d3")
         elif mode == "dark":
-            window_acrylic(self, Dark=True)
+            window_acrylic(self, Dark=True, Low=low)
+            self.configure(background="#000000")
         self.update()
 
     acrylic = wm_acrylic
@@ -926,5 +940,6 @@ class DevToplevel(tk.Toplevel, DevWindow):
 
 if __name__ == '__main__':
     Root = DevWindow()
-    Root.acrylic(mode=Light, mica=False)
+    Root.mica()
+    Root.acrylic()
     Root.run()
